jacinle.jit.cython.jit\_compile
===============================

.. automodule:: jacinle.jit.cython.jit_compile

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CythonCompiledFunction
      CythonJITCompiler
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      jit_cython
   
   

   
   
   








.. rubric:: Class CythonCompiledFunction
.. autoclass:: CythonCompiledFunction
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CythonJITCompiler
.. autoclass:: CythonJITCompiler
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: jit_cython


